#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_content.shared.common.zmi.properties module

This module defines base classes for properties edit forms.
"""

from zope.interface import implementer

from pyams_zmi.interfaces.form import IPropertiesEditForm
from pyams_zmi.form import AdminEditForm


__docformat__ = 'restructuredtext'


@implementer(IPropertiesEditForm)
class PropertiesEditForm(AdminEditForm):
    """Properties edit form"""



#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from pyramid.events import subscriber
from zope.component.interfaces import ISite
from zope.interface import implementer
from zope.lifecycleevent import IObjectAddedEvent

from pyams_content.component.paragraph.interfaces import IParagraphFactorySettingsTarget
from pyams_content.reference.pictogram.interfaces import IPictogramManagerTarget
from pyams_content.shared.common.manager import SharedTool
from pyams_content.shared.common.types import TypedSharedToolMixin
from pyams_content.shared.form.interfaces import FORM_CONTENT_TYPE
from pyams_content.shared.form.interfaces import IFormManager
from pyams_fields.interfaces import ICaptchaManagerTarget
from pyams_utils.factory import factory_config
from pyams_utils.traversing import get_parent


@factory_config(IFormManager)
@implementer(ICaptchaManagerTarget, IParagraphFactorySettingsTarget, IPictogramManagerTarget)
class FormManager(SharedTool, TypedSharedToolMixin):
    """Form manager class"""

    shared_content_type = FORM_CONTENT_TYPE
    shared_content_menu = False


@subscriber(IObjectAddedEvent, context_selector=IFormManager)
def handle_added_form_manager(event):
    """Register form manager when added"""
    site = get_parent(event.newParent, ISite)
    registry = site.getSiteManager()
    if registry is not None:
        registry.registerUtility(event.object, IFormManager)



#
# Copyright (c) 2015-2023 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_content.component.illustration.portlet.interfaces module

This module provides interfaces of illustration portlet settings.
"""

from zope.interface import Interface

from pyams_portal.interfaces import IPortletSettings


__docformat__ = 'restructuredtext'


class IIllustrationPortletSettings(IPortletSettings):
    """Illustration portlet settings interface"""


class IIllustrationPortletContent(Interface):
    """Illustration portlet content getter interface

    This interface can be used by components which doesn't provide an illustration
    directly, but can provide an illustration by other methods.
    """



#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_content.reference.zmi.viewlet module

"""
import locale

from zope.interface import Interface

from pyams_content.reference import IReferenceTable
from pyams_content.zmi.viewlet.toplinks import TopTabsViewletManager
from pyams_i18n.interfaces import II18n
from pyams_skin.viewlet.menu import MenuItem
from pyams_utils.registry import get_all_utilities_registered_for
from pyams_utils.url import absolute_url
from pyams_viewlet.manager import viewletmanager_config
from pyams_zmi.interfaces import IAdminLayer
from pyams_zmi.zmi.viewlet.toplinks import TopMenuViewletManager


__docformat__ = 'restructuredtext'

from pyams_content import _


@viewletmanager_config(name='reference-tables.menu',
                       context=Interface, layer=IAdminLayer,
                       manager=TopTabsViewletManager, weight=40)
class ReferencesTablesMenu(TopMenuViewletManager):
    """Reference tables menu"""

    label = _("Reference tables")

    def update(self):
        super().update()
        context = self.context
        request = self.request
        parent = self.__parent__
        for table in sorted(get_all_utilities_registered_for(IReferenceTable),
                            key=lambda x: locale.strxfrm(II18n(x).query_attribute('title',
                                                                                  request=request)
                                                         or '')):
            self.add_menu(context, request, parent, table)
